==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/Monitor/src/com/clustercontrol/monitor/MonitorPlugin.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.monitor;

import java.io.StringWriter;
import java.text.MessageFormat;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;

/**
 * ִƻ뵡ǽץ饰󥯥饹Ǥ
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class MonitorPlugin extends AbstractUIPlugin {

    //	 ----- static ե ----- //

    /** ץ饰Υ󥹥 */
    private static MonitorPlugin plugin = null;

    //	 ----- static ᥽å ----- //

    /**
     * ȤΥ󥹥󥹤֤ޤ
     * 
     * @return ȤΥ󥹥
     */
    public static MonitorPlugin getDefault() {
        return plugin;
    }

    /**
     * ץ饰Υ꥽Хɥꡢꤷʸ֤ޤ
     * 
     * @param key
     *            ʸ
     * @return ꤷʸ󡣥꥽Хɥ뤬̵硢⤷ϻꤷʸ ¸ߤʤϡkey֤ޤ
     */
    public static String getResourceString(String key) {
        ResourceBundle bundle = getDefault().getResourceBundle();
        try {
            return (bundle != null) ? bundle.getString(key) : key;
        } catch (MissingResourceException e) {
            return key;
        }
    }

    /**
     * ץ饰Υ꥽Хɥꡢꤷʸ֤ޤ
     * <p>
     * 
     * @param key
     *            ʸ
     * @param arguments
     *            ֤ʸ
     * @return ꤷʸ󡣥꥽Хɥ뤬̵硢⤷ϻꤷʸ ¸ߤʤϡkey֤ޤ
     * @see java.text.MessageFormat
     */
    public static String getResourceString(String key, Object[] arguments) {
        ResourceBundle bundle = getDefault().getResourceBundle();
        try {
            String message = (bundle != null) ? bundle.getString(key) : key;
            return MessageFormat.format(message, arguments);
        } catch (MissingResourceException e) {
            return key;
        }
    }

    /*
     * ͥȤˤơ侩Ƥ᥽åɷǤ
     */

    /**
     * Ϥޤ
     * 
     * @param message
     *            åʸ
     * @param e
     *            ȯ㳰
     */
    public static void log(String message, Exception e) {
        IStatus status = new Status(IStatus.ERROR, getPluginId(),
                IStatus.ERROR, message, e);
        getDefault().getLog().log(status);
    }

    /**
     * Ϥޤ
     * 
     * @param message
     *            åʸ
     */
    public static void log(String message) {
        log(message, null);
    }

    /**
     * Ϥޤ
     * 
     * @param e
     *            ȯ㳰
     */
    public static void log(Exception e) {
        StringWriter stringWriter = new StringWriter();
        String message = stringWriter.getBuffer().toString();
        log(message, e);
    }

    /**
     * ץ饰IDȤѤǤ롢ͭID֤ޤ
     * 
     * @return ץ饰ID
     * @see Bundle#getSymbolicName()
     */
    public static String getPluginId() {
        return getDefault().getBundle().getSymbolicName();
    }

    //	 ----- instance ե ----- //

    /** ꥽Хɥ */
    private ResourceBundle resourceBundle = null;

    // ----- 󥹥ȥ饯 ----- //

    /**
     * 󥹥󥹤֤ޤ
     */
    public MonitorPlugin() {
        super();
        plugin = this;
        try {
            resourceBundle = ResourceBundle
                    .getBundle("com.clustercontrol.monitor.MonitorPluginResources");
        } catch (MissingResourceException x) {
            resourceBundle = null;
        }
    }

    // ----- instance ᥽å ----- //

    /**
     * ץ饰γκݤ˸ƤФޤ
     * 
     * @param context
     *            BundleContext֥
     * @throws Exception
     *             㳰ȯ
     */
    public void start(BundleContext context) throws Exception {
        super.start(context);
    }

    /**
     * ץ饰κݤ˸ƤФޤ
     * 
     * @param context
     *            BundleContext֥
     * @throws Exception
     *             㳰ȯ
     */
    public void stop(BundleContext context) throws Exception {
        super.stop(context);
    }

    /**
     * ץ饰ݻ꥽Хɥ֤ޤ
     * 
     * @return ꥽Хɥ
     */
    public ResourceBundle getResourceBundle() {
        return resourceBundle;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/Monitor/src/com/clustercontrol/monitor/MonitorPlugin.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.monitor;

import java.io.StringWriter;
import java.text.MessageFormat;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;

/**
 * 監視管理プラグインクラスです。
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class MonitorPlugin extends AbstractUIPlugin {

    /** プラグインのインスタンス */
    private static MonitorPlugin plugin = null;
    
    /** リソースバンドルインスタンス */
    private ResourceBundle resourceBundle = null;

    /**
     * 監視管理プラグインのインスタンスを返します。
     * 
     * @return 監視管理プラグインのインスタンス
     */ 
    public static MonitorPlugin getDefault() {
        return plugin;
    }

    /**
     * 監視管理プラグインのリソースバンドルから、
     * キーに該当する文字列を返します。
     * 
     * @param key キー
     * @return 文字列。リソースバンドルが無い場合、もしくは指定した文字列 が存在しない場合は、keyを返します。
     */
    public static String getResourceString(String key) {
        ResourceBundle bundle = getDefault().getResourceBundle();
        try {
            return (bundle != null) ? bundle.getString(key) : key;
        } catch (MissingResourceException e) {
            return key;
        }
    }

    /**
     * 監視管理プラグインのリソースバンドルから、
     * キーに該当する文字列を返します。
     * 
     * @param key キー
     * @param arguments 置き換える文字列
     * @return 文字列。リソースバンドルが無い場合、もしくは指定した文字列 が存在しない場合は、keyを返します。
     * @see java.text.MessageFormat
     */
    public static String getResourceString(String key, Object[] arguments) {
        ResourceBundle bundle = getDefault().getResourceBundle();
        try {
            String message = (bundle != null) ? bundle.getString(key) : key;
            return MessageFormat.format(message, arguments);
        } catch (MissingResourceException e) {
            return key;
        }
    }

    /**
     * ログを出力します。
     * 
     * @param message ログメッセージ文字列
     * @param e 発生した例外
     */
    public static void log(String message, Exception e) {
        IStatus status = new Status(IStatus.ERROR, getPluginId(),
                IStatus.ERROR, message, e);
        getDefault().getLog().log(status);
    }

    /**
     * ログを出力します。
     * 
     * @param message ログメッセージ文字列
     * @see #log(String, Exception)
     */
    public static void log(String message) {
        log(message, null);
    }

    /**
     * ログを出力します。
     * 
     * @param e 発生した例外
     * @see #log(String, Exception)
     */
    public static void log(Exception e) {
        StringWriter stringWriter = new StringWriter();
        String message = stringWriter.getBuffer().toString();
        log(message, e);
    }

    /**
     * プラグインIDとして利用できる、固有のIDを返します。
     * 
     * @return プラグインID
     * @see Bundle#getSymbolicName()
     */
    public static String getPluginId() {
        return getDefault().getBundle().getSymbolicName();
    }

    /**
	 * コンストラクタ<BR>
	 * リソースバンドルを取得します。
	 */
    public MonitorPlugin() {
        super();
        plugin = this;
        try {
            resourceBundle = ResourceBundle
                    .getBundle("com.clustercontrol.monitor.MonitorPluginResources");
        } catch (MissingResourceException x) {
            resourceBundle = null;
        }
    }

    /**
     * プラグイン 開始。
     * プラグインの活性化の際に呼ばれます。
     * 
     * @param context BundleContextオブジェクト
     * @throws Exception
     * 
     * @see org.osgi.framework.BundleActivator#start(org.osgi.framework.BundleContext)
     */
    public void start(BundleContext context) throws Exception {
        super.start(context);
    }

    /**
     * プラグイン 停止。
     * プラグインの非活性化の際に呼ばれます。
     * 
     * @param context BundleContextオブジェクト
     * @throws Exception
     * 
     * @see org.osgi.framework.BundleActivator#stop(org.osgi.framework.BundleContext)
     */
    public void stop(BundleContext context) throws Exception {
        super.stop(context);
    }

    /**
	 * 監視管理プラグインのリソースバンドルを返します。
	 * 
	 * @return リソースバンドル
	 */
    public ResourceBundle getResourceBundle() {
        return resourceBundle;
    }
}
